@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: cf.c 295 2018-07-21 20:20:41Z leres $ (XSE)
+ * @(#) $Id: cf.c 296 2018-07-27 01:23:25Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017, 2018
  *	Craig Leres
@@ -197,7 +197,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 
 			/* Fix up path to css file and fstat() */
 			if (strcasecmp(cp3, "css") == 0) {
-				fixpath(&cf->c_css);
+				/* Check existance vs current working dir */
 				f2 = fopen(cf->c_css, "r");
 				if (f2 == NULL) {
 					fprintf(stderr,
@@ -210,10 +210,15 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 					fprintf(stderr,
 					    "%s: readcf: fstat %s: %s\n",
 					    prog, cf->c_css, strerror(errno));
+					(void)fclose(f2);
 					++errs;
 					continue;
 				}
 				(void)fclose(f2);
+
+				/* Make path relative to generated index.html */
+				fixpath(&cf->c_css);
+
 				/* Update config timestamp if css is newer */
 				ts = stattim(&sbuf);
 				if (tscmp(&cf->c_tim, &ts, <))
