@@ -1,4 +1,4 @@
-/* @(#) $Id: webindex.h 266 2015-07-04 21:39:04Z leres $ (XSE) */
+/* @(#) $Id: webindex.h 287 2017-01-21 19:15:36Z leres $ (XSE) */
 #ifndef webindex_h
 #define webindex_h
 
@@ -30,6 +30,16 @@
 #define T_XBM		17
 #define T_XWD		18
 
+/* Compare two timespec values */
+#define tscmp(p1, p2, cmp) \
+    (((p1)->tv_sec == (p2)->tv_sec) ? \
+    ((p1)->tv_nsec cmp (p2)->tv_nsec) : \
+    ((p1)->tv_sec cmp (p2)->tv_sec))
+
+/* Get newer of modified and inode times */
+#define stattim(p) \
+    (tscmp(&(p)->st_mtim, &(p)->st_ctim, >) ? (p)->st_mtim : (p)->st_ctim)
+
 extern const char *prog;
 extern int debug;
 extern int recurse;
